use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
CLI
Connects
DROLSKY
DROLSKY's
Dave
Executable
Gregory
HasVersion
Oschwald
PayPal
Pg
Postgres
Role
Rolsky
Rolsky's
autarch
createdb
drolsky
dropdb
goschwald
lib
pg_config
pg_dump
pg_restore
psql
